package Cog::App::Test;
use Mo;
extends 'Cog::App';

1;
